==> fr.opensagres.xdocreport.converter-0.9.3-sources.jar: fr/opensagres/xdocreport/converter/MimeMapping.java <==
/**
 * Copyright (C) 2011 Angelo Zerr <angelo.zerr@gmail.com> and Pascal Leclercq <pascal.leclercq@gmail.com>
 *
 * All rights reserved.
 *
 * Permission is hereby granted, free  of charge, to any person obtaining
 * a  copy  of this  software  and  associated  documentation files  (the
 * "Software"), to  deal in  the Software without  restriction, including
 * without limitation  the rights to  use, copy, modify,  merge, publish,
 * distribute,  sublicense, and/or sell  copies of  the Software,  and to
 * permit persons to whom the Software  is furnished to do so, subject to
 * the following conditions:
 *
 * The  above  copyright  notice  and  this permission  notice  shall  be
 * included in all copies or substantial portions of the Software.
 *
 * THE  SOFTWARE IS  PROVIDED  "AS  IS", WITHOUT  WARRANTY  OF ANY  KIND,
 * EXPRESS OR  IMPLIED, INCLUDING  BUT NOT LIMITED  TO THE  WARRANTIES OF
 * MERCHANTABILITY,    FITNESS    FOR    A   PARTICULAR    PURPOSE    AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
 * LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
 * OF CONTRACT, TORT OR OTHERWISE,  ARISING FROM, OUT OF OR IN CONNECTION
 * WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */
package fr.opensagres.xdocreport.converter;

/**
 * Mime mapping of the report to generate.
 * 
 */
public class MimeMapping {

	public final String extension;
	public final String mimeType;

	public MimeMapping(final String extension, final String mimeType) {
		this.extension = extension;
		this.mimeType = mimeType;
	}

	/**
	 * Returns default extension of the report (odt, docx...)
	 * 
	 * @return
	 */
	public String getExtension() {
		return extension;
	}

	/**
	 * Returns mime type of the report.
	 * 
	 * @return
	 */
	public String getMimeType() {
		return mimeType;
	}

	public String formatFileName(String reportId) {
		if (reportId.endsWith(extension)) {
			return reportId;
		}
		StringBuilder result = new StringBuilder(reportId);
		result.append('.');
		result.append(extension);
		return result.toString();
	}
}

==> fr.opensagres.xdocreport.converter-0.9.7-sources.jar: fr/opensagres/xdocreport/converter/MimeMapping.java <==
/**
 * Copyright (C) 2011 Angelo Zerr <angelo.zerr@gmail.com> and Pascal Leclercq <pascal.leclercq@gmail.com>
 *
 * All rights reserved.
 *
 * Permission is hereby granted, free  of charge, to any person obtaining
 * a  copy  of this  software  and  associated  documentation files  (the
 * "Software"), to  deal in  the Software without  restriction, including
 * without limitation  the rights to  use, copy, modify,  merge, publish,
 * distribute,  sublicense, and/or sell  copies of  the Software,  and to
 * permit persons to whom the Software  is furnished to do so, subject to
 * the following conditions:
 *
 * The  above  copyright  notice  and  this permission  notice  shall  be
 * included in all copies or substantial portions of the Software.
 *
 * THE  SOFTWARE IS  PROVIDED  "AS  IS", WITHOUT  WARRANTY  OF ANY  KIND,
 * EXPRESS OR  IMPLIED, INCLUDING  BUT NOT LIMITED  TO THE  WARRANTIES OF
 * MERCHANTABILITY,    FITNESS    FOR    A   PARTICULAR    PURPOSE    AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
 * LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
 * OF CONTRACT, TORT OR OTHERWISE,  ARISING FROM, OUT OF OR IN CONNECTION
 * WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */
package fr.opensagres.xdocreport.converter;

/**
 * Mime mapping of the report to generate.
 */
public class MimeMapping
{

    public final String extension;

    public final String mimeType;

    public MimeMapping( final String extension, final String mimeType )
    {
        this.extension = extension;
        this.mimeType = mimeType;
    }

    /**
     * Returns default extension of the report (odt, docx...)
     * 
     * @return
     */
    public String getExtension()
    {
        return extension;
    }

    /**
     * Returns mime type of the report.
     * 
     * @return
     */
    public String getMimeType()
    {
        return mimeType;
    }

    public String formatFileName( String reportId )
    {
        if ( reportId.endsWith( extension ) )
        {
            return reportId;
        }
        StringBuilder result = new StringBuilder( reportId );
        result.append( '.' );
        result.append( extension );
        return result.toString();
    }
}
